%% ===========================================================================
% Copyright (C):
%       2004-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% 
% Description   : FTW's xDSLsimu testing environment
%                 A script to run all experiments
%
% File          : runall.m
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : 
%
% CVS:       $Id:  $
%% ===========================================================================

%% ===========================================================================
% Change History
%      2005-10-27 (ToNo) Came in under revision system
%      2006-04-12 (ToNo) Added Test for SpM and make it work on 
%                        version 3.0 again
%      2006-04-13 (ToNo) Added logging of matlab/octave as well as svn version
%% ===========================================================================

% Get current date
dvec     = datevec(now);
isodate  = sprintf('%4d%02d%02d',dvec(1),dvec(2),dvec(3));

% Set up a directory for logs
logdir = sprintf('RunLogs%s',isodate);
noruns   = noFiles([logdir '*']);        % Find a unique name for logs
logdir  = sprintf('%s_r%d',logdir,noruns+1);
mkdir(logdir);
rel_logdir = sprintf('../0_Testing/%s',logdir);

diary([logdir '/LogFirst4']);
greetings
if onMatlab
    fprintf('Using Matlab Version: %s\n',version); 
else
    fprintf('Using Octave Version: %s\n',version); 
end    
fprintf('Using xdslSimu svn %s');
system(['svn info 2>&1 | grep Revision']);

cd ..  

    
% Test Simple VDSL Stuff

cd First
fprintf('\n========== Running First ==========\n\n')
startup
Main
close all
cd ..  

cd Simple
fprintf('\n========== Running Simple ==========\n\n')
ExMain
close all
cd ..

% Test SDSL

cd SDSL 
fprintf('\n========== Running ExSDSLmargin ==========\n\n')
ExSDSLmargin
close all
fprintf('\n========== Running ExSDSLmaxrate ==========\n\n')
ExSDSLmaxrate
close all
fprintf('\n========== Running ExSDSLreach ==========\n\n')
ExSDSLreach
close all
if xDSLsimuVersion>3
fprintf('\n========== Running ExSDSLreach_v2 ==========\n\n')
ExSDSLreach_v2
close all
end;
fprintf('\n========== Running ExSDSLtestloop ==========\n\n')
ExSDSLtestloop
close all
cd ..

% Test VDSL UPBO

cd PBO
fprintf('\n========== Running ExPBO ==========\n\n')
ExPBO
close all
cd ..

diary off

% Test SpM

if xDSLsimuVersion>3
cd SpM
fprintf('\n========== Running SpM ==========\n\n')
SpM
close all
% Move SpM diary to our log directory
system(['mv ' logfile ' ' rel_logdir]);
cd ..
end;    

% Test ADSL

% On k2 Pentium4@1900MHz 1h and 21 minutes
% Used time = 4885.58s (2.39s per reach)
% Calculated 25454 experiments (in avg. 13.8 experiments per nonzero reach)

% On Kale Pentium-M @ 2200MHz
% Used time = 1694.25s (0.83s per reach)

cd ADSL
fprintf('\n========== Running ADSLperf ==========\n\n')
ADSLperf

Vvars = whos('ETSI_*');
for ix = 1:length(Vvars)
    eval(['TA_' Vvars(ix).name ' = ' Vvars(ix).name ';']);
end;
eval(['save ' rel_logdir '/TA_matlab' ' TA_ETSI*']);
diary off
% TODO: test the data against the Example data
diary([rel_logdir '/LogADSLTableOut']);
fprintf('\n========== Running TableOutputRaw ==========\n\n')
TableOutputRaw
fprintf('\n========== Running TableOutputIL ==========\n\n')
TableOutputIL;
diary off
% Move ADSL diary to our log directory
if onMatlab
    system(['mv ' savefile '.mat ' rel_logdir]);
else
    system(['mv ' savefile ' ' rel_logdir]);
end;    
system(['mv ' logfile ' ' rel_logdir]);
close all
cd ..

    
cd VDSL
fprintf('\n========== Running VDSLperf ==========\n\n')
VDSLperf
Vvars = whos('ETSI_*');
for ix = 1:length(Vvars)
    eval(['TV_' Vvars(ix).name ' = ' Vvars(ix).name ';']);
end;
eval(['save ' rel_logdir '/TV_matlab' ' TV_ETSI*']);
% Move VDSL diary to our log directory
if onMatlab
    system(['mv ' savefile '.mat ' rel_logdir]);
else
    system(['mv ' savefile ' ' rel_logdir]);
end;    
system(['mv ' logfile ' ' rel_logdir]);
% TODO: test the data against the Example data
close all
cd ..

cd GUI_VDSL
fprintf('\n========== Running GUI_VDSL ==========\n\n')
startup
diary([rel_logdir '/LogGUI']);
if onMatlab
    uiMain;    callbackGO
    close all
    cd ..
end;
diary off
close all
