function AdjustForNID()
%% ===========================================================================
% Copyright (C) 2001-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                     All rights reserved. 
% Description   : ADSL performance simulations, 
%                 Adjusting for noise injection device 
%
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% Reference:
%    ETSI STC TM6 Draft RTS/TM-06006 rev 10a (ADSL), 2001-05
%
% CVS:       $Id: AdjustForNID.m 752 2009-01-02 13:03:52Z tono $
%% ===========================================================================

%% ===========================================================================
% Change History
%      2001-12-14 (ToNo) Created
%      2002-01-21 (ToNo) Changed the way I handle R_V and R_N in my simulation
%      2003-11-03 (ToNo) Lists now use cell arrays for both Octave and Matlab
%      2005-05-10 (ToNo) Fixed the "speedup" calculation for Znom
%% ===========================================================================
global ex;
global result;

plotit = 0;

Zx = 4000;
Rv = 100;

%% ===========================================================================
% Define the total calibration impedance (only once for speed sake)
if ~isfield(ex.param,'Znom')
w=2*pi*ex.param.frequency.f;
Zcal = 120 + ...
       1./(1/150 + j*w*47e-9) + ...
       1./(1/750 + j*w*150e-9);

ex.param.Znom = 1./(1./Zcal + 1./Zx + 1./Rv);
end;

%% ===========================================================================
% Define the total "actual" impedance (i.e. with the line there)

Rx=100; % ex.param.Zterm;
segs = length(ex.tt.topology);
[Zlt, Znt] = getZin(ex,1,segs,ex.tt.topology,ex.param.frequency.f,Rx);

if plotit,
    figure;
    f = ex.param.frequency.f;
    semilogx(f,abs(Zlt),'g',f,abs(Znt),'b',f,abs(Zcal),'r');
    legend('Zlt','Znt','Zcal');
end;

ZactualLT = 1./(1./Zlt + 1./Zx + 1./Rv); 
ZactualNT = 1./(1./Znt + 1./Zx + 1./Rv); 

%% ===========================================================================
% Calculate the power adjustment needed

AfactLT = abs(ZactualLT./ex.param.Znom).^2;
AfactNT = abs(ZactualNT./ex.param.Znom).^2;

if plotit,
    figure;
    semilogx(f,10*log10(abs(AfactLT)),'g');

    figure;
    semilogx(f,10*log10(abs(AfactNT)),'b');
end;

%% ===========================================================================
% Adjust the results

rlen = length(result);
for pos = 1:rlen,
    rr=result{pos};
    rr.NT.Tot_noise.up   = rr.NT.Tot_noise.up.*AfactNT;
    rr.NT.Tot_noise.down = rr.NT.Tot_noise.down.*AfactNT;
    rr.LT.Tot_noise.up   = rr.LT.Tot_noise.up.*AfactLT;
    rr.LT.Tot_noise.down = rr.LT.Tot_noise.down.*AfactLT;
    result{pos}=rr;
end;


