%% ===========================================================================
% Copyright (C):
%       1998-2000 by Telia Research AB, Lulea, Sweden;
%       2000-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% 
% Description   : Main simulation program, example of local defintions
%
% File          : ExMain.m
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se) 
%
% CVS:       $Id: ExMain.m 752 2009-01-02 13:03:52Z tono $
%% ===========================================================================

%% ===========================================================================
% Change History
%      1998-11-13 (ToNo) Created
%      1998-12-21 (ToNo) Updated to get in sync with uiMain
%      1998-01-07 (ToNo) Removed modem under test
%      1998-01-14 (ToNo) Updated to get in sync with uiMain
%      1999-02-05 (DaB)  Updated to fit new param structure
%      1999-02-25 (ToNo) Generlized list (tfplist) handling
%      1999-02-26 (ToNo) Split out definitions into userDefinitionsExample1
%      1999-03-25 (ToNo) Restructured the source (moved into subdir xdslcomm)
%      2000-04-05 (UvAn) New return value from itu_tfplanHAM
%      2003-11-03 (ToNo) Lists now use cell arrays for both Octave and Matlab
%      2005-01-04 (ToNo) Removing some unused definitions
%% ===========================================================================
global ex;
global gui;

% Set up default experiment structures
ex.param    = setupParam;                  % Set up basic parameters

ex.tfplist  = fsan_modelsMISC([]);         % Get PSDs for alien noise
ex.lclist   = setupLClist;                 % Line code definition (theoretical)
ex.lclist   = etsi_lcdefsVDSL(ex.lclist);  % Line code definitions (VDSL)
ex.clist    = etsi_cablesVDSL([]);         % Get ETSI (and ANSI) cables;

userDefinitionsExample1;

% Show traffic and topology structure
figure(1);
plotTTstructure(ex.tt);

% Show PSD masks for VDSL modem
tfplan = getList(ex.tfplist,gui.vdslDuplex);
figure(2);
gui.fax.min=1e3; gui.fax.max=12e6;
plotTFplan(tfplan,'Lin',gui.fax);

drawnow; % Show it now

% Evaluate this experiment
result = evalExperiment;

% Show the result from the experiment (Note: Mixed ADSL and VDSL results)
format compact
[bitrate_LT, bitrate_NT]=calcXDSLresult(ex,result); 

sprintf('LT Rates')
bitrate_LT
sprintf('NT Rates')
bitrate_NT
sprintf('Ratio')
bitrate_NT./bitrate_LT

% Plot the results from experiment 
for current=1:length(result),
    figure;

    x=result{current};

    tmp_str=sprintf('xDSL Simulation Result, Modem %d (%s-%s)',...
	current, ex.tt.topology{x.Modem.LT_Node}{3},...
	ex.tt.topology{x.Modem.NT_Node}{3});
    if onMatlab
        set(gcf,'NumberTitle','off','Name',tmp_str);
    end

    % Plot the LT side
    subplot(211)
    plotResult(ex,result,current,'LT');

    % Plot the NT side
    subplot(212)
    plotResult(ex,result,current,'NT');
end
% or do uiResults(ex,result) to get the gui interface for the results
