function scen = getScenario_SpM(Scenario)
%% ===========================================================================
%getScenario - Get the parameters for a specific scenario
%
% Parameter:    Scenario       Scenario name
% Returns:      scen           Resulting structure containing the parameters
%
% Reference:
%    
%% ===========================================================================
%% ===========================================================================
% Copyright (C):
%       2003-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : BANG, FTW
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: getScenario.m 556 2004-12-30 15:37:50Z tono $
%% ===========================================================================
% Change History
%      2003-11-11 (ToNo) Created
%      2004-01-14 (ToNo) Simulation of reference scenarios completed
%      2005-01-14 (ToNo) Split up into smaller parts
%      2005-04-21 (ToNo) Added support to run variations of SDSL
%% ===========================================================================
global ex;

%sdslbase = 'ETSI-SDSL-RC-';
sdslbase = 'ETSI-SDSL-';
% No VCC unless specified
vcc=[]; 
vccno=[];

switch Scenario
 case {'HPM'}
  %Noise HP/M (also 98)
  ntt= {
      {[sdslbase, 'sym-1024'],     5, -1}
      {[sdslbase, 'sym-2048'],    10, -1}
      {'ETSI-HDSL-2B1Q-2p',    3*2, -1}
      {'ETSI-HDSL-CAP-2p',     2*2, -1}
      {'ETSI-ADSL-FDDoverPOTS', 75, -1}
      {'ETSI-ADSL-FDDoverISDN', 25, -1}
      {'ETSI-VDSL-E1U0-Pex-P2-M2-D',12, -1}
      {'ETSI-ISDN-2B1Q',        75, -1}
      {'NewSys',            0, -1}
       };
  nosystems = [5 10 3*2 2*2 75 25 12 50+25 0;
               5 10 3*2-2 2*2 75-7 25-3 12 50+25 12];
  refsys = [1,2,3,4,7];
  avsys = [5,6,7];
 case {'HPR_VCC'}
  %Noise HP/R
  ntt= {
      {[sdslbase, 'sym-256'],      0, -1}
      {[sdslbase, 'sym-512'],      0, -1}
      {[sdslbase, 'sym-1024'],    16, -1}
      {[sdslbase, 'sym-2048'],    16, -1}
      {'ETSI-HDSL-CAP-2p',     3*2, -1}
      {'ETSI-ADSL-ECoverPOTS',  63, -1}
      {'ETSI-ADSL-FDDoverPOTS', 96, -1}
      {'ETSI-ADSL-ECoverISDN',  21, -1}
      {'ETSI-ADSL-FDDoverISDN', 32, -1}
      {'ETSI-VDSL-E1U0-Pex-P2-M2-D',25, -1}
      {'ETSI-ISDN-2B1Q',        97+53, -1}
      {'NewSys',            0, -1}
       };
  nosystems = [0 0 16 16 3*2 63 96 21 32 25 97+53 0;
               0 0 16 16 3*2 63-8 96-12 21-2 32-3 25 97+53 25];
  refsys = [1,2,3,4,5,10];
  avsys = [6:10];
  vcc =[1,2,3,4];
  vccno = [0,0,16,16; 0,0,32,0; 0,32,0,0; 32,0,0,0];
 case {'MPP_VCC'}
  %Noise MP/P (also 998)
  ntt= {
      {[sdslbase, 'sym-256'],      0, -1}
      {[sdslbase, 'sym-512'],      0, -1}
      {[sdslbase, 'sym-1024'],     4, -1}
      {[sdslbase, 'sym-2048'],     5, -1}
      {'ETSI-HDSL-2B1Q-2p',      2, -1}
      {'ETSI-ADSL-FDDoverPOTS', 25, -1}
      {'ETSI-VDSL-E1U0-Pex-P2-M2',5, -1}
      {'ETSI-ISDN-2B1Q',        14, -1}
      {'NewSys',            0, -1}
       };
  nosystems = [0 0 4 5 2 25-5 5 14 0;
               0 0 4 5 2 25 5 14 5];
  refsys = [1:4,5,7];
  avsys = [6,7];
  vcc =[1:4];
  vccno = [0,0,4,5; 0,0,9,0; 0,9,0,0; 9,0,0,0];
 case {'MPP'}
  %Noise MP/P (also 998)
  ntt= {
      {[sdslbase, 'sym-1024'],     4, -1}
      {[sdslbase, 'sym-2048'],     5, -1}
      {'ETSI-HDSL-2B1Q-2p',      2, -1}
      {'ETSI-ADSL-FDDoverPOTS', 25, -1}
      {'ETSI-VDSL-E1U0-Pex-P2-M2',5, -1}
      {'ETSI-ISDN-2B1Q',        14, -1}
       {'NewSys',           0, -1}
      };
  nosystems = [4 5 2 25 5 14 0;
               4 5 2 25-5 5 14 5];
  refsys = [1,2,3,5];
  avsys = [4,5];
 case {'MPI'}
  %Noise MP/I
  ntt= {
      {[sdslbase, 'sym-1024'],     4, -1}
      {[sdslbase, 'sym-2304'],     5, -1}
      {'ETSI-HDSL-2B1Q-2p',      2, -1}
      {'ETSI-ADSL-FDDoverISDN', 25, -1}
      {'ETSI-VDSL-E2-Pex-P1-M1',5, -1}
      {'ETSI-ISDN-4B3T',     14+30, -1}
      {'NewSys',            0, -1}
       };
  nosystems = [4 5 2 25 5 14+30 0;
               4 5 2 25-5 5 14+30 5];
  refsys = [1,2,3,5];
  avsys = [4,5];
  
 case {'MPM'}
  %Noise MP/M (also 998)
  ntt= {
      {[sdslbase, 'sym-1024'],     4, -1}
      {[sdslbase, 'sym-2048'],     5, -1}
      {'ETSI-HDSL-2B1Q-2p',      2, -1}
      {'ETSI-ADSL-FDDoverPOTS', 18, -1}
      {'ETSI-ADSL-FDDoverISDN',  7, -1}
      {'ETSI-VDSL-E1U0-Pex-P2-M1',5, -1}
      {'ETSI-ISDN-2B1Q',      14+7, -1}
      {'NewSys',            0, -1}
       };
  nosystems = [4 5 2 18 7 5 14+7 0;
               4 5 0 18-2 7-1 5 14+7 5];
  refsys = [1,2,3,6];
  avsys = [4,5,6];

 case {'Single'}
  ntt= {
%      {[sdslbase, 'sym-1024',   25, -1}
%      {[sdslbase, 'sym-2048',   25, -1}
%      {'ETSI-HDSL-2B1Q-2p',    25, -1}
%      {'ETSI-HDSL-CAP-2p',     25, -1}
      {'ETSI-VDSL-E2-Pex-P1-M1',     25, -1}
      {'ETSI-VDSL-E2-Pex-P1-M1',     25, -1}
       };
  nosystems = [25 25];
  refsys = [1];
  avsys = [2];
 otherwise
  error('No such scenario')
end

scen.ntt = ntt;
scen.nosystems = nosystems;
scen.refsys = refsys;
scen.avsys = avsys;
scen.vcc= vcc;
scen.vccno = vccno;