function param = setupParam(vdslDuplex)
%% ===========================================================================
%setupParam - Sets up the experiment description structure for
% a certain xDSL simulation experiment.
%
% Parameter:    vdslDuplex	String describing vdsl duplex method under test
% Returns:      param		Structure describing the experiment parameters
%
% Example(s):
%   param = setupParam; 
%
% Algorithmic details:
%   Fill in the ex.param structure according to default parameters and input
%   parameters.
%
% Reference:
%    FTW's xDSLsimu manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1998-2000 by Telia Research AB, Lulea, Sweden;                
%       2001-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%               : Bo Engstrom (bosse@upzide.com)
%
% CVS:       $Id: setupParam.m 752 2009-01-02 13:03:52Z tono $
%% ===========================================================================
% Change History
%      1998-10-19 (ToNo) Created
%      1998-11-13 (ToNo) Splitted setup into three parts param,tfplan,tt
%      1998-12-11 (DaB)  Added HAM band on/off (1/0)
%      1998-12-21 (ToNo) Moved efficiencyLoss into TF plans
%      1999-01-05 (ToNo) Changed how modem under test was defined and
%                        added the possibility of precalculated noise models
%      1999-02-04 (DaB)  Added XTlevel for NEXT,FEXT,3CXT
%      1999-03-30 (DaB)  Corrected thirdCXT value
%      1999-08-11 (DaB)  Added Zterm
%      2000-04-06 (UvAn) Added new param; expNoise
%      2001-06-14 (Bosse) Octave port
%      2001-07-05 (ToNo) Split up the background noise into LT and
%                        NT sides, and made it a string for evaluation
%      2001-10-08 (ToNo) Added support for NEXT with fourth order terms
%      2002-07-31 (ToNo) To speed up calculations we can flag that the
%                        frequency should not be recalculate in evalExperiment
%      2003-11-03 (ToNo) Lists now use cell arrays for both Octave and Matlab
%      2004-08-06 (ToNo) As this defaults to ETSI param, turn on NEXTx4
%      2008-08-29 (ToNo) As DMT systems are most used, granularity=4.3125kHz
%                        Removed the expNoise as it only brings confusion
%% ===========================================================================

%% ===========================================================================
% System parameters
% Check arguments
if nargin<1,
        vdslDuplex='TBD';
end

frequency.set             = 0;    % 1 if evalExperiment should leave f as is
frequency.fastrecalc      = 1;		% 1 if fast calaculations should
frequency.min             = 1;    	% Min frequency (Hz) to use
frequency.max             = 30e6;    	% Max frequency (Hz) to use 
frequency.granularity     = 4.3125e3;  	% Granularity (Hz) in the frequency
% Derived parameters
frequency.f  = (frequency.min:frequency.granularity:frequency.max);
param.frequency=frequency;

param.bgNoise.LT          = '-160';	% Background noise at LT (dBm/Hz)
param.bgNoise.NT          = '-160';	% Background noise at NT (dBm/Hz)
param.XTlevel.NEXT        = -50;        % Reference value at 1MHz
param.XTlevel.NEXTslant   = 15;         % Slant of NEXT in dB/decade
param.XTlevel.NEXTx4      = 1;          % Flag for forth order next modeling
param.XTlevel.FEXT        = -45;	% Reference value at 1MHz
param.XTlevel.FEXTslant   = 20;   	% Slant of FEXT in dB/decade
param.XTlevel.thirdCXT    = -75;        %         
param.Zterm               = 135;        % ref. impedance for Attenuation calc.
param.modemlist           = str2mat('VDSL');                                   
param.HAMBandName         = '';         % Name of hamband to use
param.NoiseModel          = 'Calculate'; % Noise model to use if not Calculate

tmp_xDSL.name='VDSL';
tmp_xDSL.used=vdslDuplex;
param.xDSLlist{1}=tmp_xDSL; 

