function lclist = etsi_lcdefsSDSL(lclist)
%% ===========================================================================
% etsi_lcdefsSDSL(lclist) - Sets up the tfplan for ETSI SDLS tfplans
%
% Parameter:    lclist	   Structure describing line code dependent stuff
% Returns:      lclist		Structure describing line code dependent stuff
%
% Example(s):
%   ex.lclist = etsi_lcdefsSDSL(ex.lclist);   % Add to existing lclist
%   lc = getList(ex.lclist,'ETSI-SDSL-sym');  % Get SDSL sym. line code stuff
%
%   ex.lclist = etsi_lcdefsSDSL([]);          % Create a new lclist
%   lc = getList(ex.lclist,'ETSI-SDSL-asym'); % Get SDSL asym. line code stuff
%
%
% References:
%   Draft ETSI TS 101524-2 V1.1.1 (2000-05)
%
%   ETSI TR 101 830-2,  Spectral management on metallic access
%   networks; Part 2: Technical  methods and performance
%   evaluations, m01p20a5
%% ===========================================================================

%% ===========================================================================
% Copyright (C): 
%           2000-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                      All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Gernot Schmid (schmid@ftw.at)                     %
%% ===========================================================================
% Change History
%      2000-02-10 (GS)   Created with values from SDSL performance evaluation
%      2005-01-10 (ToNo) Updated with new info from ETSI SpM work    
%% ===========================================================================

% Older lc definitions according to ETSI SDSL Reach Calculations (RC)    
% "Symmetrical" SDSL params
basic_lc       = lcDefSDSL_sym;
basic_lc.name  = 'ETSI-SDSL-RC-sym';
lclist         = insertList(lclist,basic_lc);

%---------------------------------------------------
% "Asymmetrical" SDSL params
basic_lc       = lcDefSDSL_asym;
basic_lc.name  = 'ETSI-SDSL-RC-asym';
lclist         = insertList(lclist,basic_lc);

%% ===========================================================================

% ETSI SpM Part-2 updated "Symmetrical" SDSL params
basic_lc       = lcDefSDSL_sym;
basic_lc.name  = 'ETSI-SDSL-sym';

% Change SNR gap parameters:
basic_lc.param.refSNR         = 9.75;
basic_lc.param.SNRloss        = 1.6;
basic_lc.param.codingGain     = 5.1; 
% Note that the new coding gain should be 4.4 dB at 256 kbit/s and below

% Calculate the required SNR
basic_lc.param.reqSNR           = 27.74 ...
    - basic_lc.param.codingGain + basic_lc.param.SNRloss;

lclist         = insertList(lclist,basic_lc);

%---------------------------------------------------
% ETSI SpM Part-2 updated "Asymmetrical" SDSL params
basic_lc       = lcDefSDSL_asym;

% Change SNR gap parameters:
basic_lc.param.refSNR         = 9.75;
basic_lc.param.SNRloss        = 1.6;
basic_lc.param.codingGain     = 5.1; 

% Calculate the required SNR
basic_lc.param.reqSNR           = 27.74 ...
    - basic_lc.param.codingGain + basic_lc.param.SNRloss;

basic_lc.name = 'ETSI-SDSL-asym';
lclist         = insertList(lclist,basic_lc);

