function tfplist = etsi_noisesVDSL(tfplist)
%% ===========================================================================
%etsi_noisesVDSL(tfplist) - Sets up the tfplans for some standard alien systems
%
% Parameter:    tfplist	        Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = etsi_noisesVDSL(ex.tfplist);           Add to existing tfplist
%   tfplan=getList(ex.tfplist,'ETSI-VDSL-NoiseA') ;     Get this VDSL noise
%
%   ex.tfplist = etsi_noisesVDSL([]);                   Create a new tfplist
%   tfplan=getList(ex.tfplist,'ETSI-VDSL-NoiseB');      Get this VDSL noise
%
%  Mask definitions:
%    ETSI VDSL standard Part 1, Version 2.0.7 (2003-01)
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1999-2000 by Telia Research AB, Lulea, Sweden;                
%       2000-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: etsi_noisesVDSL.m 752 2009-01-02 13:03:52Z tono $
%% ===========================================================================
% Change History
%      1999-07-01 (Dab)  Created
%      1999-08-12 (DaB)  Corrected noise model F (wrong values in ETSI doc)
%      1999-10-25 (ToNo) Reorganized things into etsi,ansi,itu,fsan definitions
%      2002-08-23 (ToNo) Split the noises into different technologies
%      2003-04-22 (ToNo) Made a minimal (0.1 dB) correction in noise C
%% ===========================================================================

%% ===========================================================================
% Use a template, as order is important!

def_tfplan = templateTFP;

%% ===========================================================================
% VDSL FTTCab noises A-C

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-VDSL-NoiseA';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -30.6 100e3 -34.2 292e3 -35.3 400e3 -43.7 1.104e6 -52.6 2.5e6 -99.6 3.637e6 -111.3 30e6 -111.5],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -29.3 100e3 -30.8 138e3 -31 150e3 -34.2 166e3 -35.3 292e3 -35.4 400e3 -46.3 900e3 -74.5 1.104e6 -79.6 1.4e6 -82 2.5e6 -99.8 3.2e6 -103.5 4.545e6 -103.9 30e6 -103.9],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-VDSL-NoiseB';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -30.7 100e3 -34.4 135e3 -35.3 139e3 -35.1 292e3 -35.3 400e3 -43.7 552e3 -46.7 956e3 -74.5 1.8e6 -83.3 2e6 -93.1 3.637e6 -111.3 30e6 -111.5],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -22.2 50e3 -22.1 75e3 -29.3 100e3 -30.8 138e3 -31 150e3 -34.2 166e3 -35.3 292e3 -35.4 400e3 -46.3 900e3 -74.5 1.104e6 -79.6 1.4e6 -82 2.5e6 -99.8 3.2e6 -103.5 4.545e6 -103.9 30e6 -103.9],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-VDSL-NoiseC';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 75e3 -30.6 100e3 -34.2 292e3 -35.3 400e3 -43.6 500e3 -45.4 900e3 -46.5 1.024e6 -46.9 1.4e6 -50.7 1.8e6 -60.6 16.5e6 -103.1 30e6 -109.8],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -22.2 50e3 -22.1 75e3 -29.3 100e3 -30.8 138e3 -31 150e3 -34.2 166e3 -35.3 292e3 -35.4 400e3 -46 500e3 -49.1 900e3 -47.1 1.024e6 -47.3 1.4e6 -50.7 1.8e6 -60.6 16.5e6 -101.7 30e6 -103.7],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

%% ===========================================================================
% VDSL FTTEx noises D-F

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-VDSL-NoiseD';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -18.2 50e3 -18.2 75e3 -25.1 117e3 -26.6 138e3 -25.4 290e3 -25.4 330e3 -25.8 1.104e6 -26 2.5e6 -66 4.53e6 -96 30e6 -96.4],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -18.2 50e3 -18.1 75e3 -24.2 275e3 -25.4 400e3 -40.6 600e3 -54.3 1e6 -71.6 2.75e6 -95.7 30e6 -96.4],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-VDSL-NoiseE';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 77e3 -30.9 117e3 -35 140e3 -30.2 292e3 -30.3 330e3 -30.6 550e3 -30.6 600e3 -32.5 700e3 -33.4 1.104e6 -33.5 4.53e6 -100.7 30e6 -101.1],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([4e3 -22.2 50e3 -22.0 71e3 -27.8 145e3 -30 175e3 -31 274e3 -31 400e3 -46.5 600e3 -60.3 1.0e6 -77.1 1.4e6 -82.2 2.8e6 -100.3 30e6 -101.1],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);

tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-VDSL-NoiseF';
tmp_tfplan.PSD.downstream='calcPSD([4e3 -22.2 50e3 -22.2 74e3 -30.3 117e3 -35 140e3 -30.2 292e3 -30.3 330e3 -30.6 550e3 -30.6 600e3 -32.5 700e3 -33.4 1.104e6 -33.5 2.1e6 -64.6 2.45e6 -63.6 16.5e6 -99.1 30e6 -101],''Log-Linear'',ex.param.frequency.f)';
tmp_tfplan.PSD.upstream='calcPSD([0.004e6 -22.2 0.05e6 -22. 0.071e6 -27.8 0.145e6 -30. 0.175e6 -31. 0.274e6 -31. 0.45e6 -47.5 0.9e6 -45.3 1.2e6 -46.7 1.5e6 -50.4 1.78e6 -58.3 16.5e6 -99.1 30e6 -101.],''Log-Linear'',ex.param.frequency.f)';
tfplist=insertList(tfplist,tmp_tfplan);



