function VDSL2profiles = itu_VDSL2profiles()
%% ===========================================================================
%itu_VDSL2profiles(tfplist) - Sets up tfplans for 
%                                   standard ITU VDSL2 masks AnnexA
%
% Parameter:    
% Returns:      VDSL2profiles	Structure describing the time and freq plan
%
% Example(s):
%   VDSL2profiles = itu_VDSL2profiles();
%   profilenames = VDSL2profiles{1,:};
%   ParamSet = VDSL2profiles{2:10,:};
%   CarrierIndex = VDSL2profiles{11:22,:};
%
% References:
%    ITU G.993.2 (02/2006 prepublish) 
 %    Table 6-1/G.993.2 - VDSL2 profiles from 
%    Draft amendment 1 to Recommendation G.993.2 (G.993.2 Amendment 1 AAP R2)
%    2007-04-NapaValley
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2008-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id:  $
%% ===========================================================================
% Change History
%      2008-03-19 (ToNo) Created 
%% ===========================================================================

df  = 4.3125e3;                  % delta f (carrier BW) for ADSL;

%% ===========================================================================
% Table 6-1/G.993.2 - VDSL2 profiles from 
% Draft amendment 1 to Recommendation G.993.2 (G.993.2 Amendment 1 AAP R2)
% 2007-04-NapaValley
VDSL2profiles = {...
    {'8a', '8b', '8c', '8d', '12a', '12b', '17a', '30a'};... % Profile Name
    {17.5,20.5,11.5,14.5,14.5,14.5,14.5,14.5};...            % Max DS power
    {+14.5,+14.5,+14.5,+14.5,+14.5,+14.5,+14.5,+14.5};...    % Max US power
    {df,df,df,df,df,df,df,df*2};...                          % CarrierSpacing
    {1,1,1,1,1,0,0,-1};...                                   % US0 support
    {50,50,50,50,68,68,100,200};...                          % MinBiDirDataRate
    {65536,65536,65536,65536,65536,65536,98304,131072};...   % Agg IL delay
    {2048,2048,2048,2048,2048,2048,3072,4096};...            % Max IL depth
    {24,24,24,24,24,24,48,28};...                            % DS IL param 1/S
    {12,12,12,12,24,24,24,28};...                            % US IL param 1/S
    {1971,1971,1971,1971,1971,1971,4095,2666};...  % Annex A DS upper edge
    {1205,1205,1205,1205,2782,2782,2782,3478};...  % Annex A US upper edge
    {1971,1971,1971,1971,1971,1971,4095,3478};...  % Annex B 998E DS upper edge
    {1205,1205,1205,1205,2782,2782,3246,2885};...  % Annex B 998E US upper edge
    {1971,1971,1971,1971,1971,1971,4095,2885};...  % Annex B 998ADE DS upper edge
    {1205,1205,1205,1205,2782,2782,2782,3478};...  % Annex B 998ADE US upper edge
    {1634,1634,1634,1634,1634,1634,3246,3130};...  % Annex B 997E DS upper edge
    {2047,2047,1182,2047,2782,2782,4095,3478};...  % Annex B 997E US upper edge
    {-1,-1,-1,-1,-1,-1,4095,3478};...              % Annex B HPE DS upper edge
    {-1,-1,-1,-1,-1,-1,3246,2885};...              % Annex B HPE US upper edge
    {1971,1971,1971,1971,1971,1971,4095,2098};...  % Annex C DS upper edge
    {1205,1205,1205,1205,2782,2782,2782,3478}...   % Annex C US upper edge
};
