%% ===========================================================================
%etsi_VDSL2tfplan_tables - Defines tables from ITU VDSL2 AnnexB
%
% References:
%    ETSI 081t15r1 VDSL2 AnnexB proposal
%    ITU G.993.2 (02/2006 prepublish) 
%    ITU Draft amendment 1 to Recommendation G.993.2 (2007-04-NapaValley)
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2007-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id:  $
%% ===========================================================================
% Change History
%      2007-03-14 (ToNo) Created from ITU G.993.2 (02/2006 prepublish) AnnexB
%      2008-03-19 (ToNo) Recreated from ETSI 081t15r1
%% ===========================================================================

% ===========================================================================
% Table 6-1/G.993.2 - VDSL2 profiles

% VDSL2profiles = itu_VDSL2profiles();

% ===========================================================================

% This Annex defines the various band plans required for European deployment
% of VDSL2 systems operating at a maximum frequency of 30 MHz.  These are
% based on ITU-T Recommendation G.993.1 [1] band plans A and B (also referred
% to as plan 998 and plan 997, respectively).  The various band plans are
% defined in Table B-1 below and can be summarized as follows:
% 
%      Plan 997          The original plan 997 (fmax=12 MHz)
%      Plan 997E17       Plan 997 directly extended to fmax=17.664 MHz.
%      Plan 997E30       Plan 997 directly extended to fmax=30 MHz.
%      (Note :NOTE - plan 997E17 and plan 997 are truncated versions
%      of plan 997E30).
% 
%      Plan 998          The original plan 998 (fmax=12 MHz).
%      Plan 998E17       Plan 998 directly extended to fmax=17.664 MHz.
%      Plan 998E30       Plan 998 directly extended to fmax=30 MHz.
%      (NoteNOTE - plan 998E17 and plan 998 are truncated versions of
%      plan 998E30).
% 
%      Plan 998ADE17     Plan 998 extended to fmax=17.664 MHz (downstream
%                        transmission only above 12 MHz)
%      Plan 998ADE30     Plan 998 extended to fmax=30 MHz.
%      (Note :NOTE - plan 998ADE17 and plan 998 are truncated versions
%      of plan 998ADE30).
% 
%      Plan HPE17        Band plan for operation between 7.05 MHz
%                        and 17.664 MHz.
%      Plan HPE30        Band plan for operation between 7.05 MHz and 30 MHz.
%      (Note :NOTE - plan HPE17 is a truncated version of plan HPE30).
% 
% Different variants are defined for band plans 997, 998, 998ADE17, 998E17,
% and 998E30, 998ADE17 and 998ADE30 to accommodate different underlying
% services (POTS and ISDN), and different US0 bandwidths.


% ===========================================================================
%    Table B-1/G.993.2 - Band-edge frequencies for European VDSL2 band plans
% 

Fplan_997X  = [25,138,3000,5100,7050,12000,14000,19500,27000,30000];
Fplan_998X  = [25,138,3750,5200,8500,12000,14000,21450,24890,30000];
Fplan_998AX = [25,138,3750,5200,8500,12000,24890,30000];
Fplan_HP    = [7050,7050,10125,12000,14000,21450,24890,30000];


% Definitions: The fi in Table B-1 are defined as follows:
% 
%     . f0L and f0H : define lower and upper frequency of US0;
% 
%     . f1 to f5 are the boundary frequencies of the bands DS1, US1, DS2, US2
%       as defined for VDSL1 for 997 and 998;
% 
%     . f5 to f9 are the boundary frequencies for the bands US3, DS3, US4 and
%       DS4 (extended bands);
% 
%     . The extension of an existing band is considered as a separate band
%       (e.g., 998E17: US3 12MHz-14MHz).


% ===========================================================================
% Table B-2/G.993.2 - European Limit PSD mask options for band plans 997 (and
%                     its extensions), HPE17 and HPE30*


%{'Short Name','Limit PSD mask','US0 type','Frequency'}

TableB2 = {
{'B7-1','997-M1c-A-7','A',7050}
{'B7-2','997-M1x-M-8','M',8832}
{'B7-3','997-M1x-M','M',12000}
{'B7-4','997-M2x-M-8','M',8832}
{'B7-5','997-M2x-A','A',12000}
{'B7-6','997-M2x-M','M',12000}
{'B7-7','HPE17-M1-NUS0','N/A',17664}
{'B7-8','HPE30-M1-NUS0','N/A',30000}
{'B7-9','997E17-M2x-A','A',17664}
{'B7-10','997E30-M2x-NUS0','N/A',30000}
};
%NOTE - The US0 types stand for:
%* US0 type A corresponds to Annex A of Recommendation G.992.5;
%* US0 type B corresponds to Annex B of Recommendation G.992.5;
%* US0 type M corresponds to Annex M of Recommendation G992.3/G.992.5;
%* US0 type N/A designates a band plan variant that does not use US0.



% ===========================================================================
%  Table B-3/G.993.2- European Limit PSD mask options for band plan
%                     998 (and its extensions)

TableB3 = {
{'B8-1','998-M1x-A','A',12000}
{'B8-2','998-M1x-B','B',12000}
{'B8-3','998-M1x-NUS0','N/A',12000}
{'B8-4','998-M2x-A','A',12000}
{'B8-5','998-M2x-M','M',12000}
{'B8-6','998-M2x-B','B',12000}
{'B8-7','998-M2x-NUS0','N/A',12000}
{'B8-8','998E17-M2x-NUS0','N/A',17664}
{'B8-9','998E17-M2x-NUS0-M','N/A',17664}
{'B8-10','998ADE17-M2x-NUS0-M','N/A',17664}
{'B8-11','998ADE17-M2x-A','A',17664}
{'B8-12','998ADE17-M2x-B','B',17664}
{'B8-13','998E30-M2x-NUS0','N/A',30000}
{'B8-14','998E30-M2x-NUS0-M','N/A',30000}
{'B8-15','998ADE30-M2x-NUS0-M','N/A',30000}
{'B8-16','998ADE30-M2x-NUS0-A','N/A',30000}
};
%NOTE - The US0 types stand for:
%* US0 type A corresponds to Annex A of Recommendation G.992.5;
%* US0 type B corresponds to Annex B of Recommendation G.992.5;
%* US0 type M corresponds to Annex M of Recommendation G992.3/G.992.5;
%* US0 type N/A designates a band plan variant that does not use US0;
%* 998Exx-M2x-NUS0-M designate the variants in which DS1 starts at
%  276kHz instead of 138kHz



% The Template PSD is set 3.5 dB below the PSD mask in frequency bands
% in which the PSD is at or above -96.5 dBm/Hz. Elsewhere the template
% is set to -100 dBm/Hz below 4 MHz, -110 dBm/Hz between 4 MHz and f3,
% or -112 dBm/Hz between f3 and 30 MHz, where f3 is defined in Table
% B-1/G.993.2. These values are chosen to satisfy the requirements of
% Section 7.2.2.


% ===========================================================================
%  Table B-4/G.993.2 - UpstreamVTU-R Limit PSD masks for band plans 997 (and
%                      its extensions), HPE17 and HPE30

%{B7-1,B7-2,B7-3,B7-4,B7-5,B7-6,B7-7,B7-8,B7-9,B7-10};
%{997-M1-c-A-7,997-M1-x-M-8,997-M1-x-M,997-M2x-M-8,997-M2x-A,997-M2x-M,HPE17-M1-NUS0,HPE30-M1-NUS0,997E17-M2x-A,997E30-M2x-NUS0};
% See TableB2

p1Hz = 0.001; % Added to brick wall steps to make them less steep.
DoInterp = 999;

TableB4 = [
[0,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-100,-100,-97.5,-100];
[4,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-100,-100,-97.5,-100];
[4+p1Hz,-92.5,-92.5,-92.5,-92.5,-92.5,-92.5,-100,-100,-92.5,-100];
[25.88,-34.5,-37.5,-37.5,-37.5,-34.5,-37.5,-100,-100,-34.5,-100];
[50,-34.5,-37.5,-37.5,-37.5,-34.5,-37.5,-100,-100,-34.5,-100];
[80,-34.5,-37.5,-37.5,-37.5,-34.5,-37.5,-100,-100,-34.5,-100];
[120,-34.5,-37.5,-37.5,-37.5,-34.5,-37.5,-100,-100,-34.5,-100];
[138,-34.5,-37.5,-37.5,-37.5,-34.5,-37.5,-100,-100,-34.5,-100];
[225,DoInterp,-37.5,-37.5,-37.5,DoInterp,-37.5,-100,-100,DoInterp,-100];
[243,-93.2,-37.5,-37.5,-37.5,-93.2,-37.5,-100,-100,-93.2,-100];
[276,DoInterp,-37.5,-37.5,-37.5,DoInterp,-37.5,-100,-100,DoInterp,-100];
[493.41,DoInterp,-97.9,-97.9,-97.9,DoInterp,-97.9,-100,-100,DoInterp,-100];
[686,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[2825,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[3000,-80,-80,-80,-80,-80,-80,-100,-100,-80,-80];
[3000+p1Hz,-56.5,-56.5,-56.5,-50.3,-50.3,-50.3,-100,-100,-50.3,-50.3];
[3575,-56.5,-56.5,-56.5,DoInterp,DoInterp,DoInterp,-100,-100,DoInterp,DoInterp];
[3750,-56.5,-56.5,-56.5,DoInterp,DoInterp,DoInterp,-100,-100,DoInterp,DoInterp];
[5100,-56.5,-56.5,-56.5,-52.6,-52.6,-52.6,-100,-100,-52.6,-52.6];
[5100+p1Hz,-80,-80,-80,-80,-80,-80,-100,-100,-80,-80];
[5275,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[6875,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[7050,-100,-80,-80,-80,-80,-80,-100,-100,-80,-80];
[7050+p1Hz,-100,-56.5,-56.5,-54,-54,-54,-100,-100,-54,-54];
[8325,-100,-56.5,-56.5,DoInterp,DoInterp,DoInterp,-100,-100,DoInterp,DoInterp];
[9950,-100,-56.5,-56.5,DoInterp,DoInterp,DoInterp,-100,-100,DoInterp,DoInterp];
[10125,-100,-56.5,-56.5,-55.5,-55.5,-55.5,-80,-80,-55.5,-55.5];
[10125+p1Hz,-100,-56.5,-56.5,-55.5,-55.5,-55.5,-56.5,-56.5,-55.5,-55.5];
[12000,-100,-56.5,-56.5,-55.5,-55.5,-55.5,-56.5,-56.5,-55.5,-55.5];
[12000+p1Hz,-100,-80,-80,-80,-80,-80,-56.5,-56.5,-80,-80];
[12175,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-100,-100];
[13825,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-100,-100];
[14000,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-80,-80];
[14000+p1Hz,-100,-100,-100,-100,-100,-100,-80,-80,-56.5,-56.5];
[14175,-100,-100,-100,-100,-100,-100,-100,-100,DoInterp,DoInterp];
[17664,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5];
[19500,-100,-100,-100,-100,-100,-100,-100,-100,-80,-56.5];
[19500+p1Hz,-100,-100,-100,-100,-100,-100,-100,-100,-80,-80];
[19675,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[21275,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[21450,-100,-100,-100,-100,-100,-100,-100,-80,-100,-100];
[21450+p1Hz,-100,-100,-100,-100,-100,-100,-100,-56.5,-100,-100];
[24890,-100,-100,-100,-100,-100,-100,-100,-56.5,-100,-100];
[24890+p1Hz,-100,-100,-100,-100,-100,-100,-100,-80,-100,-100];
[25065,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[26825,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[27000,-100,-100,-100,-100,-100,-100,-100,-100,-100,-80];
[27000+p1Hz,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5];
[30000,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5];
[30000+p1Hz,-110,-110,-110,-110,-110,-110,-110,-110,-110,-80];
[30175,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110];
];

% NOTE - The PSD values between breakpoints including the values
% marked by "DoInterp" shall be obtained by interpolation between
% adjacent breakpoints as follows:
%  - below 2825kHz on a dB / log(f) basis, and
%  - above 2825kHz on a dB / f basis

% NOTE - In the Limit PSD masks B7-2 and B7-4, the PSD above 8832 kHz
% should be considered preliminary. Reduction in the mask in the band
% from 8832 kHz to 12000 kHz is for further study. The minimum roll-off
% of the anti-alias filter should be specified to limit unnecessary
% FEXT to full bandwidth solutions sharing the same cable, to protect
% the amateur radio band (10.10 MHz to 10.15 MHz), and to provide
% flexibility for future band plan evolution.


% ===========================================================================
% Table B-5/G.993.2 - DownstreamVTU-O Limit PSD masks for band plans 997 (and
%                      its extensions), HPE17 and HPE30

%[B7-1,B7-2,B7-3,B7-4,B7-5,B7-6,B7-7,B7-8,B7-9,B7-10];
%[997-M1c-A-7,997-M1x-M-8,997-M1x-M,997-M2x-M-8,997-M2x-A,997-M2x-M,HPE17-M1-NUS0,HPE30-M1-NUS0,997E17-M2x-A,997E30-M2x-NUS0,];
% See TableB2

TableB5 = [
[0,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5];
[4,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5];
[4+p1Hz,-92.5,-92.5,-92.5,-92.5,-92.5,-92.5,-97.5,-97.5,-92.5,-92.5];
[80,-72.5,-92.5,-92.5,-92.5,-72.5,-92.5,-97.5,-97.5,-72.5,-72.5];
[101.2,DoInterp,-92.5,-92.5,-92.5,DoInterp,-92.5,-97.5,-97.5,DoInterp,DoInterp];
[138,-49.5,DoInterp,DoInterp,DoInterp,-44.2,DoInterp,-100,-100,-44.2,-44.2];
[138+p1Hz,-49.5,DoInterp,DoInterp,DoInterp,-36.5,DoInterp,-100,-100,-36.5,-36.5];
[227.11,-49.5,-62,-62,-62,-36.5,-62,-100,-100,-36.5,-36.5];
[276,-49.5,-48.5,-48.5,-48.5,-36.5,-48.5,-100,-100,-36.5,-36.5];
[276+p1Hz,-49.5,-36.5,-36.5,-36.5,-36.5,-36.5,-100,-100,-36.5,-36.5];
[1104,-49.5,-36.5,-36.5,-36.5,-36.5,-36.5,-100,-100,-36.5,-36.5];
[1622,-49.5,-46.5,-46.5,-46.5,-46.5,-46.5,-100,-100,-46.5,-46.5];
[2208,-49.5,-48,-48,DoInterp,DoInterp,DoInterp,-100,-100,DoInterp,DoInterp];
[2236,-49.5,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,-100,-100,DoInterp,DoInterp];
[2249,-49.5,-49.5,-49.5,DoInterp,DoInterp,DoInterp,-100,-100,DoInterp,DoInterp];
[2423,-56.5,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,-100,-100,DoInterp,DoInterp];
[2500,-56.5,-56.5,-56.5,DoInterp,DoInterp,DoInterp,-100,-100,DoInterp,DoInterp];
[3000,-56.5,-56.5,-56.5,-49.6,-49.6,-49.6,-100,-100,-49.6,-49.6];
[3000+p1Hz,-80,-80,-80,-80,-80,-80,-100,-100,-80,-80];
[3175,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[4925,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[5100,-80,-80,-80,-80,-80,-80,-100,-100,-80,-80];
[5100+p1Hz,-56.5,-56.5,-56.5,-52.6,-52.6,-52.6,-100,-100,-52.6,-52.6];
[5200,-56.5,-56.5,-56.5,DoInterp,DoInterp,DoInterp,-100,-100,DoInterp,DoInterp];
[6875,-56.5,-56.5,-56.5,DoInterp,DoInterp,DoInterp,-100,-100,DoInterp,DoInterp];
[7050,-56.5,-56.5,-56.5,-54,-54,-54,-80,-80,-54,-54];
[7050+p1Hz,-80,-80,-80,-80,-80,-80,-56.5,-56.5,-80,-80];
[7225,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-100,-100];
[10125,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-100,-100];
[10125+p1Hz,-100,-100,-100,-100,-100,-100,-80,-80,-100,-100];
[10300,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[11825,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[12000,-100,-100,-100,-100,-100,-100,-100,-100,-80,-80];
[12000+p1Hz,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5];
[13825,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5];
[14000,-100,-100,-100,-100,-100,-100,-80,-80,-56.5,-56.5];
[14000+p1Hz,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-80,-80];
[14175,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-100,-100];
[17664,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-100,-100];
[19325,-100,-100,-100,-100,-100,-100,DoInterp,-56.5,-100,-100];
[19500,-100,-100,-100,-100,-100,-100,DoInterp,-56.5,-100,-80];
[19500+p1Hz,-100,-100,-100,-100,-100,-100,DoInterp,-56.5,-100,-56.5];
[21000,-100,-100,-100,-100,-100,-100,-80,-56.5,-100,-56.5];
[21450,-100,-100,-100,-100,-100,-100,-100,-56.5,-100,-56.5];
[21450+p1Hz,-100,-100,-100,-100,-100,-100,-100,-80,-100,-56.5];
[21625,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5];
[24715,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5];
[24890,-100,-100,-100,-100,-100,-100,-100,-80,-100,-56.5];
[24890+p1Hz,-100,-100,-100,-100,-100,-100,-100,-56.5,-100,-56.5];
[27000,-100,-100,-100,-100,-100,-100,-100,-56.5,-100,-56.5];
[27000+p1Hz,-100,-100,-100,-100,-100,-100,-100,-56.5,-100,-80];
[27175,-100,-100,-100,-100,-100,-100,-100,-56.5,-100,-100];
[30000,-100,-100,-100,-100,-100,-100,-100,-56.5,-100,-100];
[30000+p1Hz,-110,-110,-110,-110,-110,-110,-110,-80,-110,-110];
[30175,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110];
];

% NOTE - The PSD values between breakpoints including the values
% marked by "DoInterp" shall be obtained by interpolation between
% adjacent breakpoints as follows:
%  -  below f1 on a dB / log(f) basis, and
%  -  above f1 on a dB / f basis,
% where f1 is defined in Table B-1 as either 138 or 276kHz.

% For Limit PSD masks B7-7 and B7-8, where f1 is N/A, the PSD values
% between breakpoints including the values marked by "DoInterp" shall be
% obtained by interpolation between adjacent breakpoints as follows:
%  -  below 138 kHz on a dB / log(f) basis, and
%  -  above 138 kHz on a dB / f basis.


% ===========================================================================
%  Table B-6/G.993.2 - UpstreamVTU-R Limit PSD masks for band plan 998 (and
%                               its extensions)

%[B8-1,B8-2,B8-3,B8-4,B8-5,B8-6,B8-7,B8-8,B8-9,B8-10,B8-11,B8-12,B8-13,B8-14,B8-15,B8-16];
%[998-M1-x-A,998-M1x-B,998-M1x-NUS0,998-M2x-A,998-M2x-M,998-M2x-B,998-M2x-NUS0,998E17-M2x-NUS0,998E17-M2x-NUS0-M,998ADE17-M2x-NUS0-M,998ADE17-M2x-A,998ADE17-M2x-B,998E30-M2x-NUS0,998E30-M2x-NUS0-M,998ADE30-M2x-NUS0-M,998ADE30-M2x-NUS0-A];
% See TableB3

TableB6 = [
[0,-97.5,-97.5,-100,-97.5,-97.5,-97.5,-100,-100,-100,-100,-97.5,-97.5,-100,-100,-100,-100];
[4,-97.5,-97.5,-100,-97.5,-97.5,-97.5,-100,-100,-100,-100,-97.5,-97.5,-100,-100,-100,-100];
[4+p1Hz,-92.5,-92.5,-100,-92.5,-92.5,-92.5,-100,-100,-100,-100,-92.5,-92.5,-100,-100,-100,-100];
[25.88,-34.5,-92.5,-100,-34.5,-37.5,-92.5,-100,-100,-100,-100,-34.5,-92.5,-100,-100,-100,-100];
[50,-34.5,-90,-100,-34.5,-37.5,-90,-100,-100,-100,-100,-34.5,-90,-100,-100,-100,-100];
[80,-34.5,-81.8,-100,-34.5,-37.5,-81.8,-100,-100,-100,-100,-34.5,-81.8,-100,-100,-100,-100];
[120,-34.5,-34.5,-100,-34.5,-37.5,-34.5,-100,-100,-100,-100,-34.5,-34.5,-100,-100,-100,-100];
[138,-34.5,-34.5,-100,-34.5,-37.5,-34.5,-100,-100,-100,-100,-34.5,-34.5,-100,-100,-100,-100];
[225,DoInterp,-34.5,-100,DoInterp,-37.5,-34.5,-100,-100,-100,-100,DoInterp,-34.5,-100,-100,-100,-100];
[243,-93.2,-34.5,-100,-93.2,-37.5,-34.5,-100,-100,-100,-100,-93.2,-34.5,-100,-100,-100,-100];
[276,DoInterp,-34.5,-100,DoInterp,-37.5,-34.5,-100,-100,-100,-100,DoInterp,-34.5,-100,-100,-100,-100];
[307,DoInterp,DoInterp,-100,DoInterp,DoInterp,DoInterp,-100,-100,-100,-100,DoInterp,DoInterp,-100,-100,-100,-100];
[493.41,DoInterp,DoInterp,-100,DoInterp,-97.9,DoInterp,-100,-100,-100,-100,DoInterp,DoInterp,-100,-100,-100,-100];
[508.8,DoInterp,-98,-100,DoInterp,DoInterp,-98,-100,-100,-100,-100,DoInterp,-98,-100,-100,-100,-100];
[686,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[3575,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[3750,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80];
[3750+p1Hz,-56.5,-56.5,-56.5,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2];
[5100,-56.5,-56.5,-56.5,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp];
[5200,-56.5,-56.5,-56.5,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7];
[5200+p1Hz,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80];
[5375,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[8325,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[8500,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80];
[8500+p1Hz,-56.5,-56.5,-56.5,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8];
[10000,-56.5,-56.5,-56.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5];
[12000,-56.5,-56.5,-56.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5,-55.5];
[12000+p1Hz,-80,-80,-80,-80,-80,-80,-80,-56.5,-56.5,-80,-80,-80,-56.5,-56.5,-80,-80];
[12175,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-100,-100,-100,-56.5,-56.5,-100,-100];
[14000,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-100,-100,-100,-56.5,-56.5,-100,-100];
[14000+p1Hz,-100,-100,-100,-100,-100,-100,-100,-80,-80,-100,-100,-100,-80,-80,-100,-100];
[14175,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[21275,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[21450,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-80,-80,-100,-100];
[21450+p1Hz,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-100,-100];
[24715,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-100,-100];
[24890,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-80,-80];
[24890+p1Hz,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-80,-80,-56.5,-56.5];
[25065,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5];
[30000,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5];
[30000+p1Hz,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-80,-80];
[30175,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110];
];

%  NOTE - The PSD values between breakpoints including the values marked by
%  ``Interp'' shall be obtained by interpolation between adjacent
%  breakpoints as follows:
%          *       below 3575kHz on a dB / log(f) basis, and
%          *       above 3575kHz on a dB / f basis.



% ===========================================================================
% Table B-7/G.993.2 - DownstreamVTU-O Limit PSD masks for band plan 998 (and
%                               its extensions)

%[B8-1,B8-2,B8-3,B8-4,B8-5,B8-6,B8-7,B8-8,B8-9,B8-10,B8-11,B8-12,B8-13,B8-14,B8-15,B8-16];
%[998-M1x-A,998-M1x-B,998-M1x-NUS0,998-M2x-A,998-M2x-M,998-M2x-B,998-M2x-NUS0,998E17-M2x-NUS0,998E17-M2x-NUS0-M,998ADE17-M2x-NUS0-M,998ADE17-M2x-A,998ADE17-M2x-B,998E30-M2x-NUS0,998E30-M2x-NUS0-M,998ADE30-M2x-NUS0-M,998ADE30-M2x-NUS0-A];
% See TableB3

TableB7 = [
[0,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5];
[4,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5,-97.5];
[4+p1Hz,-92.5,-92.5,-92.5,-92.5,-92.5,-92.5,-92.5,-92.5,-92.5,-92.5,-92.5,-92.5,-92.5,-92.5,-92.5,-92.5];
[80,-72.5,-92.5,-72.5,-72.5,-92.5,-92.5,-72.5,-72.5,-92.5,-92.5,-72.5,-92.5,-72.5,-92.5,-92.5,-72.5];
[101.2,DoInterp,-92.5,DoInterp,DoInterp,-92.5,-92.5,DoInterp,DoInterp,-92.5,-92.5,DoInterp,-92.5,DoInterp,-92.5,-92.5,DoInterp];
[138,-44.2,DoInterp,-44.2,-44.2,DoInterp,DoInterp,-44.2,-44.2,DoInterp,DoInterp,-44.2,DoInterp,-44.2,DoInterp,DoInterp,-44.2];
[138+p1Hz,-36.5,DoInterp,-36.5,-36.5,DoInterp,DoInterp,-36.5,-36.5,DoInterp,DoInterp,-36.5,DoInterp,-36.5,DoInterp,DoInterp,-36.5];
[227.11,-36.5,-62,-36.5,-36.5,-62,-62,-36.5,-36.5,-62,-62,-36.5,-62,-36.5,-62,-62,-36.5];
[276,-36.5,-48.5,-36.5,-36.5,-48.5,-48.5,-36.5,-36.5,-48.5,-48.5,-36.5,-48.5,-36.5,-48.5,-48.5,-36.5];
[276+p1Hz,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5];
[1104,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5,-36.5];
[1622,-46.5,-46.5,-46.5,-46.5,-46.5,-46.5,-46.5,-46.5,-46.5,-46.5,-46.5,-46.5,-46.5,-46.5,-46.5,-46.5];
[2208,-48,-48,-48,-48,-48,-48,-48,-48,-48,-48,-48,-48,-48,-48,-48,-48];
[2249,-49.5,-49.5,-49.5,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp];
[2500,-56.5,-56.5,-56.5,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp];
[3750,-56.5,-56.5,-56.5,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2,-51.2];
[3750+p1Hz,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80];
[3925,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[5025,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[5200,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80];
[5200+p1Hz,-56.5,-56.5,-56.5,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7,-52.7];
[7050,-56.5,-56.5,-56.5,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp];
[7225,-56.5,-56.5,-56.5,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp,DoInterp];
[8500,-56.5,-56.5,-56.5,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8,-54.8];
[8500+p1Hz,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80,-80];
[8675,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[11825,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100];
[12000,-100,-100,-100,-100,-100,-100,-100,-100,-100,-80,-80,-80,-100,-100,-80,-80];
[12000+p1Hz,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-56.5,-100,-100,-56.5,-56.5];
[13825,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-56.5,-100,-100,-56.5,-56.5];
[14000,-100,-100,-100,-100,-100,-100,-100,-80,-80,-56.5,-56.5,-56.5,-80,-80,-56.5,-56.5];
[14000+p1Hz,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-56.5,-56.5,-56.5,-56.5,-56.5,-56.5,-56.5];
[17664,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-56.5,-56.5,-56.5,-56.5,-56.5,-56.5,-56.5];
[21000,-100,-100,-100,-100,-100,-100,-100,-80,-80,-80,-80,-80,-56.5,-56.5,-56.5,-56.5];
[21450,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-56.5,-56.5];
[21450+p1Hz,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-80,-80,-56.5,-56.5];
[21625,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5];
[24715,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5];
[24890,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-80,-80,-56.5,-56.5];
[24890+p1Hz,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-80,-80];
[25065,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-100,-100];
[30000,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-100,-56.5,-56.5,-100,-100];
[30000+p1Hz,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-80,-80,-110,-110];
[30175,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110,-110];
];

% NOTE - The PSD values between breakpoints including the values
% marked by DoInterp shall be obtained by interpolation between
% adjacent breakpoints as follows:
%  -  below f1 on a dB / log(f) basis, and
%  -  above f1 on a dB / f basis,
% where f1 is defined in Table B-1 as either 138 or 276kHz.

