function lc = lcDefISDNMMS43
%% ===========================================================================
% lcDefISDN - Sets up the lincode description structure for
%             ISDN/MMS43
%
% Returns:       lc	The linecode structure
%
% References:	
%    Draft ETSI TR 101 830-2 V1.2.1 (2008-xx); pds:m06p06a02_SpM2_DR
%    Chen W., "DSL simulation techniques and standards development
%    for DSL systems"
%    Starr T., J. Cioffi, P. Silverman "Understanding DSL technology", 1999
%    The xDSL simulation tool manual, FTW 2000
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 2008-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                     All rights reserved. 
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: lcDefISDNMMS43.m,v 1.3 2005/01/04 10:32:28 tono Exp $
%% ===========================================================================
% Change History
%      2008-08-25 (ToNo) Created as a placeholder for MMS43 Rx model
%% ===========================================================================

lc.name           	  = 'ETSI-ISDN-MMS43';

% FIXME - make this setup actually correspond to MMS43 and not 2B1Q
% as it is now

lc.param.signal_margin    = 0;
lc.param.xtalk_margin     = 6;

% refSNR                    = 9.75;
codingGain                = 0;  
SNRloss                   = 1.6;

bps                       = 2;        % 2B1Q

% Calculate the req SNR [Starr]:
M  = 2^(bps);
Pe = 1e-7;
ei = erfinv(1-Pe./(1-1./M));
lc.param.reqSNR           = 10*log10((M.*M-1).*2./3.*ei.^2) + ...
                           SNRloss - codingGain;

% Param digital
lc.param.modulation       = 'PAM';   % Modulation is 2B1Q
lc.param.mod.bpsym        = bps;    % Bits per symbol
lc.param.mod.brate.rate   = 128e3+16e3;  % Bitrate in bit per sec. (excl. overhead)
lc.param.mod.brate.ohead  = 36e3;  % Datarate overhead

lc.param.SNRMax           = 100;   % Maximum SNR usable [Chen p.524] 
lc.param.efficiencyLoss   = 0;     % General efficiency loss factor
                                   % ISDN uses SNRloss instead

lc.param.modemNoise.LT    = '-140'; % Modem noise at LT (dBm/Hz)
lc.param.modemNoise.NT    = '-140'; % Modem noise at NT (dBm/Hz)

lc.calcRate 		  = 'calcResultHDSL';
lc.lcPrint 		  = 'lcPrintHDSL';
