function lc = lcDefVDSLDMT
%% ===========================================================================
%lcDefVDSLDMT - Sets up the lincode description structure for DMT
% Returns:      lc	The linecode structure
%
% Example(s):
%
% Algorithmic details:
%   Fill in the modemdef structure according to default parameters and input
%   parameters.
%
% Reference:
%    FTW's xDSLsimu manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C):
%       1999-2000 by Telia Research AB, Lulea, Sweden;
%       2000-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: lcDefVDSLDMT.m 752 2009-01-02 13:03:52Z tono $
%% ===========================================================================
% Change History
%      1999-10-11 (ToNo) Created
%      2000-01-12 (Dab)  lc function changed
%      2000-04-04 (Dab)  Added signal margin
%      2001-07-03 (ToNo) Added active tones
%      2001-09-12 (ToNo) Add support for "Maximum aggregate transmit power"
%      2003-12-16 (ToNo) Split background noise into bgNoise and modemNoise
%      2003-12-16 (ToNo) We now use data symbol rate calculations so that
%                        efficiencyLoss should defaults to 0
%      2003-12-18 (DrSt) Split "Param digital" in downstream and
%                        upstream parameters
%% ===========================================================================

lc.name           	= 'VDSL-DMT';

% Default Parameter values

% get the margin
lc.param.signal_margin  = 0;
lc.param.xtalk_margin   = 6;
lc.param.refSNR         = 9.8;
lc.param.codingGain     = 3.5;
lc.param.SNRloss        = 0;
lc.param.PxDown         = 11.5;
lc.param.PxUp           = 11.5;

%% ===========================================================================
% Parameter that are DMT specific
lc.param.dmt.df		   = 4.3125e3;     % Carrier spacing 

%%% Downstream parameters
lc.param.dmt.ds.carriers   = 4096;         % Number of carriers used
lc.param.dmt.ds.fs         = lc.param.dmt.df*lc.param.dmt.ds.carriers*2; % Sampling frequency
lc.param.dmt.ds.cp         = 640;          % Downstream cyclic prefix value
lc.param.dmt.ds.cs         = 0;            % Downstream cyclic suffix value
lc.param.dmt.ds.my         = 0;            % Sampels used for windowing
lc.param.dmt.ds.beta       = 0;            % Sampels used for pulse shaping

%%% Upstream parameters
lc.param.dmt.us.carriers   = 4096;         % Number of carriers used
lc.param.dmt.us.fs         = lc.param.dmt.df*lc.param.dmt.us.carriers*2; % Sampling frequency
lc.param.dmt.us.cp         = 640;          % Upstream cyclic prefix value
lc.param.dmt.us.cs         = 0;            % Upstream cyclic suffix value
lc.param.dmt.us.my         = 0;            % Sampels used for windowing
lc.param.dmt.us.beta       = 0;            % Sampels used for pulse shaping

% NOTE: These tones are preliminary, the actual tones used is for
% further study.

% Set up active tones (default is set to plan 997)
% 997 tones 32         695        1182        1634        2782
lc.param.dmt.us.tones    = [   699:1178   1638:2782]; % Upstream active tones
lc.param.dmt.ds.tones    = [32:691  1186:1630];       % Downstream active tones

% 998 tones 32         869        1205        1971        2782
%lc.param.dmt.us.tones    = [   874:1200   1976:2782]; % Upstream active tones
%lc.param.dmt.ds.tones    = [32:865  1210:1966];       % Downstream active tones

%% ===========================================================================

lc.param.dmt.srate         = 4e3;        % DMT data symbol rate
lc.param.constellation     = (2:15);     % bit constellation supported
lc.param.SNRMax            = 58;         % 15*3 + (9.8+6-3.5)=57.3

%lc.param.efficiencyLoss = 1-2*lc.param.dmt.carriers./ ...
%    (lc.param.dmt.cp+lc.param.dmt.cs+lc.param.dmt.my+...
%     lc.param.dmt.beta+lc.param.dmt.carriers*2);
lc.param.efficiencyLoss    = 0;
lc.param.alpha             = 0;

lc.param.modemNoise.LT     = '-140'; % Modem noise at LT (dBm/Hz)
lc.param.modemNoise.NT     = '-140'; % Modem noise at NT (dBm/Hz)

lc.calcRate 		   = 'calcResultDMT';
lc.lcPrint 		   = 'lcPrintDMT';
