function Pout=modelPSD_ISDN2B1Q(f)
%% ===========================================================================
% modelPSD_ISDN2B1Q - PSD mask for ISDN 2B1Q
%
% Parameter:    f	Frequency axis
% Returns:      Pout	PSD mask (in mW)
%
% Example(s):
%   
% Algorithmic details:
%   
% Reference:
%    ETSI TM6 SpM part 2
%% ===========================================================================

%% ===========================================================================
% Copyright (C):
%       2003-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: modelPSD_ISDN2B1Q.m,v 1.2 2005/01/04 10:25:12 tono Exp $
%% ===========================================================================
% Change History
%      2003-11-24 (ToNo) Created
%% ===========================================================================

fx     = 80e3;
fl     = 0;
fh1    = fx;
Nh1    = 2;
qN     = 1.1257;
Ptot   = 10^(13.5/10);
Pfloor = 10^(-120/10);


P1 = Ptot * ( 2 * qN /fx ) * sinc(f/fx).^2 .* (1 ./ (1+(fl./f).^2)) ...
     .* (1 ./ (1+(f./fh1).^(2*Nh1))) ;

Pout = max(P1,Pfloor);
