function Pout=modelPSD_ISDN_MMS43(f)
%% ===========================================================================
% modelPSD_ISDN_MMS43 - PSD mask for ISDN MMS43 (aka ISDN 4B3T)
%
% Parameter:    f	Frequency axis
% Returns:      Pout	PSD mask (in mW)
%
% Example(s):
%   
% Algorithmic details:
%   
% Reference:
%    ETSI TM6 SpM part 2 Version 1.2.1
%% ===========================================================================

%% ===========================================================================
% Copyright (C):
%       2008-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: modelPSD_ISDN2B1Q.m,v 1.2 2005/01/04 10:25:12 tono Exp $
%% ===========================================================================
% Change History
%      2008-03-17 (ToNo) Created
%% ===========================================================================

f0     = 120e3;
fp1    = 1020e3;
fp2    = 1860e3;
fl1    = 80e3;
fl2    = 1020e3;

Ptot   = 10^(13.5/10);
Pfloor = 10^(-125/10);


P1 = Ptot * ( 2 /f0 ) * ...
     (sinc(f/f0).^2 + sinc((f-fp1)/f0).^2 + sinc((f-fp2)/f0).^2 ).* ...
     (1 ./ (1+(f./fl1).^4)) .* (1 ./ (1+(f./fl2).^4)) ;

Pout = P1+Pfloor;
