function PSD=modelPSD_SDSL_v121(lcname,f,dir)
%% ===========================================================================
% modelPSD_SDSL_v121 - Calculates PSDs for SDSL coded 16 PAM,
%                      for 
%                      Both symmetrical and asymetrical SDSL.
%
% Parameter:    lcname    Linecode name
% 		f         Frequency
%               dir       True (1) if it is the downstream (LTU)
% Returns:      PSD       Resulting SDSL PSD
%
%
% References:
%   Draft ETSI TR 101 830-2 V1.2.1 (2008-xx); pds:m06p06a02_SpM2_DR
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 
%       2008-2009 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                     All rights reserved. 
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: modelPSD_SDSL_sym_SpM.m,v 1.3 2005/01/04 10:32:28 tono Exp $
%% ===========================================================================
% Change History
%      2008-03-17 (ToNo) Created according version 1.2.1 of SpM Part2
%      2008-08-28 (ToNo) Introduced consistent naming (pam -> mod)
%% ===========================================================================
global ex

if nargin<3,
    dir=1;
end;

lc=getList(ex.lclist,lcname);

bits_per_sym = lc.param.mod.bpsym;           % Payload bits per PAM symbol
brate        = lc.param.mod.brate.rate;      % Payload bit rate 
overh        = lc.param.mod.brate.ohead;     % Overhead
R            = ex.param.Zterm; 	             % Line termination impedance

fl           = 5e3;                          % [Hz]
Pfloor       = 10^(-120/10);

% Get the other parameters for the transmit PSD
stype = ~isempty(findstr(lcname,'-sym'));
[fxfactor,fhfactor,N,K]=etsi_SDSLmodelParameters(stype,brate,dir);

fsym         = (brate+overh)/bits_per_sym;   % Transmitted symbol rate
fx           = fsym*fxfactor;
fh           = fx*fhfactor;


% Main PSD in mW/Hz
Psinc = 1e3* K/(fx*R) * sinc(f/fx).^2 ...
        .* (1 ./ (1+(f./fh).^(2*N))) .* (1 ./ (1+(fl./f).^2));           

% Add a floor
PSD = Psinc + Pfloor;


 